"""
Replace all occurences of <scriptName> with your chosen script name
Copy and paste code into notepad and save as <scriptName>.py (* All file types)
Upload file to .../<gameDirectory>/addons/eventcripts/<scriptName>/
Add the following line to your .../<gameDirectory>/cfg/autoexec.cfg:
es_load <scriptName>
Restart your server
Requires EventScripts v2.0.0.250i -> [url=http://Mattie.info/Cs]Mattie's Download Page[/url]
"""

''' Eventscript Imports '''
import es
import cfglib
import cmdlib
import playerlib
import popuplib
import services

''' Addon Information '''
info = es.AddonInfo()
info.name = "Player Management"
info.version = "1.0"
info.basename = (__name__.split(".", 1)[~0].replace(".", "/"))
info.author = "aDz"
info.description = "EventScripts v2.0.0.250i Addon: Player Management"

''' Configuration '''
cfg = cfglib.AddonCFG(es.getAddonPath(info.basename) + "/%s.cfg" % info.basename)
cfg.text("%s [v%s] Configuration" %(info.name, info.version))
cfg.text("")
cfg.text("General Settings")
adminOnly = cfg.cvar("%s_adminOnly" % info.basename, 1, "Admin Only (Boolean) [Default=1]")
commandPrefix = cfg.cvar("%s_commandPrefix" % info.basename, "@", "Command Prefix (String) [Default=\"@\"]")
announceAction = cfg.cvar("%s_announceAction" % info.basename, 1, "Announce Action (Boolean) [Default=1]")
syntaxMessage = cfg.cvar("%s_syntaxMessage" % info.basename, "Syntax = <actionCommand> <playerFilters/targetName/targetSteamid/targetUserid>", "Syntax Message (String) [Default=\"Syntax = <actionCommand> <playerFilters/targetName/targetSteamid/targetUserid>\"]")
cfg.text("")
cfg.write()

''' Data Structures '''
actionList = [
    "Burn",
    "Extinguish",
    "Freeze",
    "Godmode",
    "Kick",
    "Mortal",
    "Slay",
    "Spectator",
    "Swap",
    "Unfreeze"]
popupDict = {}

''' Wrapping Functions '''
def msg(text):
    es.msg("#multi", "#lightgreen%s #green[v%s] #default:: %s" %(info.name, info.version, text))
    
def tell(userid, text):
    es.tell(userid, "#green", text)
    
def popupHandler(popupName, selectName=None):
    popupDict['popup%s' % popupName] = popuplib.easymenu(popupName, None, globals()["popup%s_Select" % popupName] if not selectName else selectName)
    popupDict['popup%s' % popupName].settitle('%s [v%s]' %(info.name, info.version))
    popupDict['popup%s' % popupName].setdescription(':: %s' % popupName)

''' Necessary Functions '''
def load():
    msg("Loaded.")
    cfg.execute()
    cmdlib.registerClientCommand("%splayers" % commandPrefix, playerCmd, "Client Console Command: %splayers" % commandPrefix)
    cmdlib.registerSayCommand("%splayers" % commandPrefix, playerCmd, "Client Say Command: %splayers" % commandPrefix)
    for x in actionList:
        cmdlib.registerClientCommand("%s%s" %(commandPrefix, x), actionCmd, "Client Console Command: %s" % x)
        cmdlib.registerSayCommand("%s%s" %(commandPrefix, x), actionCmd, "Client Say Command: %s" % x)
    popupHandler("Main")
    for x in actionList:
        popupDict["popupMain"].addoption(x, x)
        popupHandler(x, popupAction_Select)
        for y in ("Player", "Team", "All"):
            popupDict["popup%s" % x].addoption((x, y), y)

def unload():
    msg("Unloaded.")
    cmdlib.unregisterClientCommand("%splayers" % commandPrefix)
    cmdlib.unregisterSayCommand("%splayers" % commandPrefix)
    for x in actionList:
        cmdlib.unregisterClientCommand("%s%s" %(commandPrefix, x))
        cmdlib.unregisterSayCommand("%s%s" %(commandPrefix, x))
    for x in popupDict:
        popuplib.delete(x[5:])
        
''' Authorization Services '''
def setupAuth():
    global isAuthed
    if services.isRegistered("auth"):
        auth_service = services.use("auth")
        auth_service.registerCapability("playerManagement", auth_service.ADMIN)
        isAuthed = lambda x: auth_service.isUseridAuthorized(x, "playerManagement")
    else:
        isAuthed = lambda x: False
        
setupAuth()
    
''' Registered Commands '''
def actionCmd(userid, args):
    if adminOnly and not isAuthed(userid):
        return tell(userid, "You do not have the required permissions to use this command.")
    if args:
        if es.getuserid(args) or args[0].startswith("#"):
            if args[0].startswith("#"):
                for x in playerlib.getUseridList(args[0]):
                    globals()[str.lower(es.getargv(0))[len(str(commandPrefix)):]](userid, x)
                return
            return globals()[str.lower(es.getargv(0))[len(str(commandPrefix)):]](userid, es.getuserid(args))
        return tell(userid, "Invalid Target. %s" % syntaxMessage)
    return tell(userid, "Invalid Arguments. %s" % syntaxMessage)
    
def playerCmd(userid, args):
    if adminOnly and not isAuthed(userid):
        return tell(userid, "You do not have the required permissions to use this command.")
    popupDict["popupMain"].send(userid)    
        
''' Popup Menuselects '''
def popupAction_Select(userid, choice, popupname):
    globals()[str.lower(choice[1])](userid, choice[0])
    
def popupMain_Select(userid, choice, popupName):
    popupDict["popup%s" % choice].send(userid)
    
def popupPlayer_Select(userid, choice, poupname):
    globals()[str.lower(choice[0])](userid, choice[1])
        
def popupTeam_Select(userid, choice, poupname):
    for x in filter(lambda x: es.getplayerteam(x) == int(choice[1]), es.getUseridList()):
        globals()[str.lower(choice[0])](userid, x)

def strTeam(team):
    return ("Spectator", "Terrorist", "Counter-Terrorist")[team - 1]
    
''' Filter Handlers '''
def player(userid, choice):
    popupHandler("Player", popupPlayer_Select)
    for x in es.getUseridList():
        popupDict["popupPlayer"].addoption((choice, x), es.getplayername(x))
    popupDict["popupPlayer"].send(userid)
    
def team(userid, choice):
    popupHandler("Team", popupTeam_Select)
    for x in xrange(4):
        popupDict["popupTeam"].addoption((choice, x), strTeam(x))
    popupDict["popupTeam"].send(userid)

def all(userid, choice):
    for x in es.getUseridList():
        globals()[str.lower(choice)](userid, x)
        
''' Action Handlers '''        
def burn(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).burn()
        if announceAction:
            msg("%s burned %s" %(es.getplayername(userid), es.getplayername(target)))
            
def extinguish(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).extinguish()
        if announceAction:
            msg("%s extinguished %s" %(es.getplayername(userid), es.getplayername(target)))
        
def freeze(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).freeze(1)
        if announceAction:
            msg("%s froze %s" %(es.getplayername(userid), es.getplayername(target)))
        
def godmode(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).godmode(1)
        if announceAction:
            msg("%s put %s into god mode" %(es.getplayername(userid), es.getplayername(target)))
    
def kick(userid, target):
    playerlib.getPlayer(target).kick()
    messageAction(userid, target, "kick")
    
def mortal(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).godmode(0)
        if announceAction:
            msg("%s put %s into mortal mode" %(es.getplayername(userid), es.getplayername(target)))
    
def slay(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).slay()
        if announceAction:
            msg("%s slayed %s" %(es.getplayername(userid), es.getplayername(target)))
            
def spectator(userid, target):
    es.server.queuecmd("es_changeteam %s 1" % target)
    if announceAction:
        msg("%s swapped %s to spectator" %(es.getplayername(userid), es.getplayername(target)))
        
def swap(userid, target):
    if target in playerlib.getUseridList("#ct") or target in playerlib.getUseridList("#t"):
        es.server.queuecmd("es_changeteam %s %s" %(target, (5 - es.getplayerteam(target))))
        if announceAction:
            msg("%s swapped %s" %(es.getplayername(userid), es.getplayername(target)))
            
def unfreeze(userid, target):
    if target in playerlib.getUseridList("#alive"):
        playerlib.getPlayer(target).freeze(0)
        if announceAction:
            msg("%s unfroze %s" %(es.getplayername(userid), es.getplayername(target)))